@@ -23,7 +23,8 @@ class enisebox():
             kwargs['contactListener'] = contactListener
         # le monde box2d
         self.world     = b2World(**kwargs)
-
+        # les images
+        self._images  = {}
         # les objets du monde
         self.things   = []
 
@@ -47,6 +48,7 @@ class enisebox():
         self.things.append(obj)
         return obj
 
+    # obsolète, présent pour compatibilité
     def itemconfigure(self, thing, **kwargs):
         item = thing.item
         if kwargs:
@@ -54,6 +56,10 @@ class enisebox():
         else:
             return self.canvas.itemconfigure(item)
 
+    def find_withtag(self, tagOrId):
+        ids = self.canvas.find_withtag(tagOrId)
+        return [ thing for thing in self.things if thing.item in ids ]
+
     def Step(self, *args):
         self.world.Step(*args)
         for obj in self.things:
@@ -159,6 +165,7 @@ class enisebox():
         return (int(x*self.scale), int((self._height-y)*self.scale))
 
     def find_overlapping2(self, bbox, callback):
+        # obsolète
         (x1, y1, x2, y2) = bbox
         queryCallback = ebQueryCallback2(callback)
         aabb = b2AABB(
@@ -166,15 +173,37 @@ class enisebox():
             upperBound=self.toBoxCoords(x2,y1),
         )
         self.world.QueryAABB(queryCallback, aabb)
+    #
+    # def find_overlapping3(self, x1, y1, x2, y2):
+    #     # obsolète
+    #     queryCallback = ebQueryCallback()
+    #     aabb = b2AABB(
+    #         lowerBound=self.toBoxCoords(x1,y2),
+    #         upperBound=self.toBoxCoords(x2,y1),
+    #     )
+    #     self.world.QueryAABB(queryCallback, aabb)
+    #     return queryCallback.objects
 
     def find_overlapping(self, x1, y1, x2, y2):
-        queryCallback = ebQueryCallback()
-        aabb = b2AABB(
-            lowerBound=self.toBoxCoords(x1,y2),
-            upperBound=self.toBoxCoords(x2,y1),
-        )
-        self.world.QueryAABB(queryCallback, aabb)
-        return queryCallback.objects
+        objects = []
+        for obj in self.things:
+            objBbox = self.bbox(obj)
+            if self._intersect(*objBbox, x1, y1, x2, y2):
+                objects.append(obj)
+        return objects
+
+    def _inside(self,x,y,x1,y1,x2,y2):
+        if x1<=x<=x2 and y1<=y<=y2:
+            return True
+        else:
+            return False
+
+    def _intersect(self,x1,y1,x2,y2,a1,b1,a2,b2):
+        if ( self._inside(x1,y1,a1,b1,a2,b2) or self._inside(x2,y2,a1,b1,a2,b2)
+                or self._inside(a1,b1,x1,y1,x2,y2) or self._inside(a2,b2,x1,y1,x2,y2) ):
+            return True
+        else:
+            return False
 
     @property
     def gravity(self):
@@ -186,7 +215,11 @@ class enisebox():
         self.world.gravity = value
 
     def bbox(self, thing):
-        return self.canvas.bbox(thing.item)
+        fixture = thing.body.fixtures[0]
+        bbox = fixture.GetAABB(0)
+        (x1, y2) = self.toCanvasCoords(*bbox.lowerBound)
+        (x2, y1) = self.toCanvasCoords(*bbox.upperBound)
+        return (x1, y1, x2, y2)
 
 class ebContactListener(b2ContactListener):
     def __init__(self, contactManagement):
@@ -209,7 +242,20 @@ class ebContactListener(b2ContactListener):
     def PostSolve(self, contact, impulse):
         pass
 
+# class ebQueryCallback(b2QueryCallback):
+#     # obsolète
+#     def __init__(self):
+#         b2QueryCallback.__init__(self)
+#         self.objects = []
+#
+#     def ReportFixture(self, fixture):
+#         # remember the associated thing
+#         self.objects.append(fixture.body.userData)
+#         # continues the query if returns True
+#         return True
+#
 class ebQueryCallback2(b2QueryCallback):
+    # obsolète
     def __init__(self, query):
         b2QueryCallback.__init__(self)
         self._query = query
@@ -220,17 +266,6 @@ class ebQueryCallback2(b2QueryCallback):
         # continues the query if returns True
         return self._query(thing)
 
-class ebQueryCallback(b2QueryCallback):
-    def __init__(self):
-        b2QueryCallback.__init__(self)
-        self.objects = []
-
-    def ReportFixture(self, fixture):
-        # remember the associated thing
-        self.objects.append(fixture.body.userData)
-        # continues the query if returns True
-        return True
-
 class ebRayCastCallback(b2RayCastCallback):
     # travail en cours...
     def __init__(self, raycast):
